Zoom
----

App Registration
  https://marketplace.zoom.us/develop/create

Development callback URL
    http://127.0.0.1:8000/accounts/zoom/login/callback/

Select scope user:read during app registration.
